@@ -6,7 +6,11 @@
 /*                 please contact P. L'Ecuyer at: lecuyer@iro.UMontreal.ca       */
 /* ***************************************************************************** */
 
+#ifndef WELL521a_H
+#define WELL521a_H
+
 void InitWELLRNG521a (unsigned int *init);
-double WELLRNG521a (void);
+extern double (*WELLRNG521a)(void);
+
+#endif
 
-extern void initWELL521(int tempering);
